# BatchQueryStatus

The localized status of the query task: - submitted: The query was submitted to the query executor for processing. - pending: The query was waiting for being processed. - executing: The query is being processed. - completed: The query was successfully executed. - aborted: The query execution failed. - deleted_notallowed: The query execution failed because objects included in the query do not support the querying of deleted records. 

## Enum

* `SUBMITTED` (value: `'submitted'`)

* `PENDING` (value: `'pending'`)

* `EXECUTING` (value: `'executing'`)

* `COMPLETED` (value: `'completed'`)

* `ABORTED` (value: `'aborted'`)

* `DELETED_NOTALLOWED` (value: `'deleted_notallowed'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


